NLSL: dchex.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
dchex.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | dchex (r, ldr, p, k, l, z, ldz, nz, c, s, job)

## Function/Subroutine Documentation

subroutine dchex | ( | double precision, dimension(ldr,1) | r,
|  | integer | ldr,
|  | integer | p,
|  | integer | k,
|  | integer | l,
|  | double precision, dimension(ldz,1) | z,
|  | integer | ldz,
|  | integer | nz,
|  | double precision, dimension(1) | c,
|  | double precision, dimension(1) | s,
|  | integer | job
| ) |  |

Definition at line 2 of file dchex.f90.

Here is the call graph for this function:

Here is the caller graph for this function: